#!/usr/bin/python3

# Print OS Version
# Written by: junyoung_chang <junyoung_chang@tmax.co.kr>

import sys
import getopt
import requests
import re

OS_INFO_PATH = "/etc/tmaxgooroom/info"
OS_REPO_PATH = "/etc/apt/sources.list.d/tmaxgooroom.list"
OS_INFO_URL = "/pool/main/t/tmaxgooroom-info/"
VERSION_PATTERN = re.compile('tmaxgooroom-info_[0-9]\.[0-9]\.[0-9]')

repo = None
with open(OS_REPO_PATH, 'r') as f:
    for repo_line in f.readlines():
        repo_line = repo_line.strip()

        if repo_line.startswith("#"):
            continue
        elif "deb" not in repo_line:
            continue
        
        if "/tmax" in repo_line:
            repo = repo_line.split()[1]
            OS_INFO_URL = repo + OS_INFO_URL
            break
    if not repo:
        print("[ERROR] Repository not found ({})".format(OS_REPO_PATH))
        exit()

try:
    original_text = requests.get(OS_INFO_URL).text
    version_list = []
    tmp = original_text.split()
    for t in tmp:
        if VERSION_PATTERN.search(t):
            version = VERSION_PATTERN.findall(t)[0].split("_")[-1].strip()
            version_list.append(version)
except:
    print("Please check Internet connection")
    exit()

with open(OS_INFO_PATH, 'r') as f:
    lines = f.readlines()
    for l in lines:
        if "RELEASE" in l:
            current_version = l.split("RELEASE=")[-1].strip()
            break

def main(argv):
    FILE_NAME = argv[0]

    try:
        opts, args = getopt.getopt(argv[1:], "hcnp", ["help", "current", "latest", "print"])
    except getopt.GetoptError:
        print()
        print("[USAGE]", "check-os-version", "{--current | --latest | --print}")
        print()
        sys.exit(1)

    for opt, arg in opts:
        if opt in ("-h", "--help"):
            print("[USAGE]", "check-os-version", "{--current | --latest | --print}")
        
        elif opt in ("-c", "--current"):
            print(current_version)
        
        elif opt in ("-n", "--latest"):
            print(max(version_list))
    
        elif opt in ("-p", "--print"):
            print()
            print("OS Version Information")
            print("- Current Version: {}".format(current_version))
            print("- Latest Version:  {}".format(max(version_list)))
            print()
    
    if len(argv) == 1:
        print()
        print("OS Version Information")
        print("- Current Version: {}".format(current_version))
        print("- Latest Version:  {}".format(max(version_list)))
        print()
        print("[USAGE]", "check-os-version", "{--current | --latest | --print}")
        print()

if __name__ == "__main__":
    main(sys.argv)
